==============
Wagtail OAuth2
==============

.. image:: https://github.com/gandi/wagtail-oauth2/actions/workflows/publish-doc.yml/badge.svg
   :target: https://gandi.github.io/wagtail-oauth2/
   :alt: Documentation


.. image:: https://github.com/Gandi/wagtail-oauth2/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/Gandi/wagtail-oauth2/actions/workflows/tests.yml
   :alt: Build Status


Plugin to replace Wagtail default login by an OAuth2.0 Authorization Server.

What is wagtail-oauth2
----------------------

OAuth2.0 is an authorization framework widely used and usually,
OAuth2.0 authorization servers grant authorization on authenticated user.


The OAuth2 Authorization is used as an **identity provider**.


Read More
---------

You can read the `full documentation of this library here`_.


.. _`full documentation of this library here`: https://gandi.github.io/wagtail-oauth2/
